#-----------------------------------------------------------------------------
# Name        :   Bezier Triangle Tool 2.0
# Description :   A tool to create and edit rational Bezier triangles.
# Menu Item   :   Draw->Bezier Triangle
# Context Menu:   Edit Bezier Triangle
# Usage       :   Draw->Bezier Triangle will draw a default rational Bezier 
#                 triangle and put you into the editing tool for the newly 
#                 drawn triangle.
#             :   Selecting an existing rational Bezier triangle drawn/edited
#                 with this tool and using Edit Bezier Triangle in the Right 
#                 Mouse Button context menu will also activate the editing tool
#                 for the selected triangle.
#             :   To change the weight of a non-end control point, hover the
#                 cursor over the control point you want to change the weight
#                 of so that it is highlighted in green, type the new weight
#                 you want for it, without moving the cursor away from the
#                 control point, and press enter or return to influence the 
#                 shape of the triangle.
#             :   The editing tool also allows you to select either the 10 
#                 control points or the 18 lines of the control polygon that 
#                 can be moved to manipulate the rational Bezier triangle to be
#                 the way you want it to be.
#                 Inferencing is available when the selected points are moved.
#                 Also, inference locking is available using the Shift key.
#                 If the user holds down the shift key for more than 1/2 second,
#                 then the infrences are unlocked on the release.  Otherwise, 
#                 the user presses shift once to lock and a second time to 
#                 unlock.
# Date        :   01/24/2015
# Type        :   Tool
#-----------------------------------------------------------------------------

# First we pull in the standard API hooks.
require 'sketchup.rb'
require 'extensions.rb'

#-----------------------------------------------------------------------------
module JPS
module BezierTriangle

#------------------------------------------------------------------------------
# Create the extension.
jps_beziertriangle_ext = SketchupExtension.new 'Bezier Triangle Tool',
                                               'jps_beziertriangle/beziertriangle.rb'

jps_beziertriangle_ext.description = "Use the Bezier Triangle Tool to model " +
    "smooth rational triangle patches that can be scaled indefinitely, " +
    "allowing for more natural and intricate surfaces. You can find the " +
    "Bezier Triangle Tool in the Draw menu, as well as in the Right Mouse " +
    "Button Context Menu once a Bezier triangle created/edited using this " +
    "tool is selected."

jps_beziertriangle_ext.version =  '2.0'
jps_beziertriangle_ext.creator = "Jacob Samuel"

# Register the extension with Sketchup so it shows up in the Preference panel.
Sketchup.register_extension jps_beziertriangle_ext, true

end # module BezierSurface
end # module JPS
